<?php

# This form requires wfpl. See: http://sametwice.com/wfpl

define('ADMIN_IMAGES_DB_FIELDS', 'image,name,caption');

require_once(__DIR__.'/'.'inc/wfpl/format.php');
require_once(__DIR__.'/'.'inc/wfpl/upload.php');

# example: 200x300
function format_width_height($str) {
	$fields = explode('x', $str);
	if(count($fields) != 2) {
		return '';
	}

	list($width, $height) = $fields;
	$width = format_int_0($width);
	$height = format_int_0($height);

	return "${width}x$height";
}

function admin_images_get_fields() {
	$data = array();

	$data['name'] = format_oneline(_REQUEST_cut('name'));
	$data['caption'] = format_oneline(_REQUEST_cut('caption'));

	if($_FILES['image'] && $_FILES['image']['error'] == 0 && file_exists($_FILES['image']['tmp_name'])) {
		$image_fn_ext = path_or_mime_to_ext($_FILES['image']['name'], $_FILES['image']['type']);
		$image_fn_ext = ext_to_web_image_ext($image_fn_ext);
		$image_fn_base = sha1_file($_FILES['image']['tmp_name']);
		if (strlen($image_fn_base) == 40) {
			$image_fn_base = substr($image_fn_base, 0, 16);
			$image_filename = 'cms_images/' . $image_fn_base . '.' . $image_fn_ext;
			$data['image'] = convert_uploaded_image('image', $image_filename);
		}
	} else {
		if(_REQUEST_cut('delete_image') == 'Yes') {
			$data['image'] = '';
		}
	}
	unset($_FILES['image']);

	return $data;
}


function admin_images_main() {
	session_auth_must('admin_images');

	$id = _REQUEST_cut('edit_id');
	if($id) {
		return admin_images_main_form($id);
	}

	$id = _REQUEST_cut('admin_images_delete_id');
	if($id) {
		return admin_images_main_delete($id);
	}

	if(_REQUEST_cut('new')) {
		return admin_images_main_form();
	}

	if(_REQUEST_cut('list')) {
		return admin_images_main_listing();
	}

	if(isset($_POST['name'])) {
		return admin_images_main_form();
	}

	# default action:
	return admin_images_main_listing();
}

function admin_images_main_delete($id) {
	$data = db_get_assoc('cms_images', 'image', 'where id=%i', $id);
	if ($data) {
		$src = enc_image_src($data['image']);
		if ($src) {
			$filenames = array($src);
			foreach ($GLOBALS['wfpl_image_widths'] as $w) {
				$filenames [] = substr($src, 0, -4) . 'w' . $w . substr($src, -4);
			}
			foreach ($filenames as $filename) {
				if (file_exists($filename)) {
					unlink($filename);
				}
			}
		}
		db_delete('cms_images', 'where id=%i', $id);
		message('Image deleted.');
	} else {
		message("Couldn't find image to delete. Maybe it's already been deleted?");
	}
	return './admin_images';
}

function admin_images_main_listing() {
	$sort_by = 'name';
	$sorts = array(
		'age' => 'created_at desc',
		'name' => "coalesce(nullif(name, ''), caption), created_at",
		'caption' => "coalesce(nullif(caption, ''), name), created_at"
	);
	if (isset($_REQUEST['sort'])) {
		foreach ($sorts as $s => $sql) {
			if ($_REQUEST['sort'] == $s) {
				$sort_by = $s;
				break;
			}
		}
	}
	tem_set("sort_by_$sort_by");
	$listing_rows = db_get_assocs('cms_images', 'id,image,name,caption', 'order by ' . $sorts[$sort_by]);
	tem_set('listings', $listing_rows);
}

function admin_images_main_form($id = false) {
	if($id) {
		tem_set('id', $id);
	}

	if(isset($_POST['name'])) {
		$data = admin_images_get_fields();

		# save anything
		# Note: If you change this to re-display the form in some cases, be sure to handle image uploads well (don't make them upload it again.)

		# save to database
		if($id) {
			db_update_assoc('cms_images', $data, 'where id=%i', $id);
			message('Image updated.');
			$saved_id = $id;
			return "./admin_images";
		} else {
			$data['created_at'] = time();
			db_insert_assoc('cms_images', $data);
			message('Image saved. Next time you open a page editor, this image will be availble in the "Insert Image" dialog.');
			$saved_id = db_auto_id();
			return "./admin_images?sort=age";
		}

	} elseif($id) {
		# we've recieved an edit id, but no data. So we grab the values to be edited from the database
		$data = db_get_assoc('cms_images', ADMIN_IMAGES_DB_FIELDS, 'where id=%i', $id);
	} else {
		# form not submitted, set default values:
		$data = array();
	}

	tem_set('upload_max_filesize', upload_max_filesize());

	tem_set('form', $data);
}
